| Title: | Launch a Shiny Application without Opening R or RStudio |
|---|---|
| Description: | Launch an application by a simple click without opening R or RStudio. The package has 3 functions of which only one is essential in its use, `shiny.exe()`. It generates a script in the open shiny project then create a shortcut in the same folder that allows you to launch the app by clicking.If you set `host = 'public'`, the application will be launched on the public server to which you are connected. Thus, all other devices connected to the same server will be able to access the application through the link of your `IPv4` extended by the port. You can stop the application by leaving the terminal opened by the shortcut. |
| Authors: | Abdoul Oudouss Diakité [aut, cre] |
| Maintainer: | Abdoul Oudouss Diakité <[email protected]> |
| License: | GPL-2 |
| Version: | 0.2.0 |
| Built: | 2026-06-09 07:43:33 UTC |
| Source: | https://github.com/aodiakite/shiny.exe |
hostUnix
hostUnix( appDir = getwd(), port = getOption("shiny.port"), launch.browser = getOption("shiny.launch.browser", interactive()), host = getOption("shiny.host", "127.0.0.1"), workerId = "", quiet = FALSE, display.mode = c("auto", "normal", "showcase"), test.mode = getOption("shiny.testmode", FALSE) )hostUnix( appDir = getwd(), port = getOption("shiny.port"), launch.browser = getOption("shiny.launch.browser", interactive()), host = getOption("shiny.host", "127.0.0.1"), workerId = "", quiet = FALSE, display.mode = c("auto", "normal", "showcase"), test.mode = getOption("shiny.testmode", FALSE) )
appDir |
see host parameter in shiny::runApp() |
port |
see port parameter in runApp() |
launch.browser |
see launch.browser parameter in shiny::runApp() |
host |
see host parameter in shiny::runApp() |
workerId |
see workerId parameter in shiny::runApp() |
quiet |
see quiet parameter in shiny::runApp() |
display.mode |
see display.mode parameter in shiny::runApp() |
test.mode |
see test.mode parameter in shiny::runApp() |
launch a shiny application
## Not run: hostUnix(appDir = getwd(), port = getOption("shiny.port"), launch.browser = getOption("shiny.launch.browser", interactive()), host = getOption("shiny.host", "127.0.0.1"), workerId = "", quiet = FALSE, display.mode = c("auto", "normal", "showcase"), test.mode = getOption("shiny.testmode", FALSE)) ## End(Not run)## Not run: hostUnix(appDir = getwd(), port = getOption("shiny.port"), launch.browser = getOption("shiny.launch.browser", interactive()), host = getOption("shiny.host", "127.0.0.1"), workerId = "", quiet = FALSE, display.mode = c("auto", "normal", "showcase"), test.mode = getOption("shiny.testmode", FALSE)) ## End(Not run)
hostWin
hostWin( appDir = getwd(), port = getOption("shiny.port"), launch.browser = getOption("shiny.launch.browser", interactive()), host = getOption("shiny.host", "127.0.0.1"), workerId = "", quiet = FALSE, display.mode = c("auto", "normal", "showcase"), test.mode = getOption("shiny.testmode", FALSE) )hostWin( appDir = getwd(), port = getOption("shiny.port"), launch.browser = getOption("shiny.launch.browser", interactive()), host = getOption("shiny.host", "127.0.0.1"), workerId = "", quiet = FALSE, display.mode = c("auto", "normal", "showcase"), test.mode = getOption("shiny.testmode", FALSE) )
appDir |
see host parameter in shiny::runApp() |
port |
see port parameter in runApp() |
launch.browser |
see launch.browser parameter in shiny::runApp() |
host |
see host parameter in shiny::runApp() |
workerId |
see workerId parameter in shiny::runApp() |
quiet |
see quiet parameter in shiny::runApp() |
display.mode |
see display.mode parameter in shiny::runApp() |
test.mode |
see test.mode parameter in shiny::runApp() |
launch a shiny application
## Not run: hostWin( appDir = getwd(), port = getOption("shiny.port"), launch.browser = getOption("shiny.launch.browser", interactive()), host = getOption("shiny.host", "127.0.0.1"), workerId = "", quiet = FALSE, display.mode = c("auto", "normal", "showcase"), test.mode = getOption("shiny.testmode", FALSE)) ## End(Not run)## Not run: hostWin( appDir = getwd(), port = getOption("shiny.port"), launch.browser = getOption("shiny.launch.browser", interactive()), host = getOption("shiny.host", "127.0.0.1"), workerId = "", quiet = FALSE, display.mode = c("auto", "normal", "showcase"), test.mode = getOption("shiny.testmode", FALSE)) ## End(Not run)
shiny.exe
shiny.exe( appName, port = getOption("shiny.port"), host = getOption("shiny.host", "127.0.0.1"), appDir = getwd() )shiny.exe( appName, port = getOption("shiny.port"), host = getOption("shiny.host", "127.0.0.1"), appDir = getwd() )
appName |
the name of you shortcut or application |
port |
see port parameter in shiny::runApp() |
host |
see host parameter in shiny::runApp(). If host = 'public', the application will be launched on the public server to which you are connected. Thus, all other devices connected to the same server will be able to access the application through the link of your IPv4 extended by the port. You can stop the application by leaving the terminal opened by the shortcut. |
appDir |
see host parameter in shiny::runApp() |
character(0)
## Not run: shiny.exe(appName = "MyApp", host = 'public')## Not run: shiny.exe(appName = "MyApp", host = 'public')